#' A collection of tools for RKWard plugin development.
#'
#' \tabular{ll}{
#' Package: \tab rkwarddev\cr
#' Type: \tab Package\cr
#' Version: \tab 0.06-2\cr
#' Date: \tab 2013-04-04\cr
#' Depends: \tab R (>= 2.9.0),methods,XiMpLe (>= 0.03-18),rkward (>= 0.5.6)\cr
#' Enhances: \tab rkward\cr
#' Encoding: \tab UTF-8\cr
#' License: \tab GPL (>= 3)\cr
#' LazyLoad: \tab yes\cr
#' URL: \tab http://rkward.sourceforge.net\cr
#' }
#'
#' Provides functions to create plugin skeletons and XML structures for RKWard.
#'
#' @aliases rkwarddev-package rkwarddev
#' @name rkwarddev-package
#' @docType package
#' @title The rkwarddev Package
#' @author Meik Michalke \email{meik.michalke@@hhu.de}
#' @keywords package
NULL
